class Menu(object):

    def __init__(self, days, valid_from, valid_to, allergens_legend):
        self.days = days
        self.valid_from = valid_from
        self.valid_to = valid_to
        self.allergens_legend = allergens_legend




from bs4 import BeautifulSoup
from urllib.request import Request, urlopen

def get_menu_link():
    req = Request("http://schlemmermeyle.de/speisen/?restaurant=1")
    html_page = urlopen(req)

    soup = BeautifulSoup(html_page, "lxml")

    menu_link = []

    for link in soup.findAll('a'):
        if 'Tageskarte' in link.text:
            menu_link = link.get('href')

    return menu_link



import datetime


class Date(object):

    def __init__(self, day, month):
        self.day = int(day)
        self.month = int(month)
        self.year = datetime.date.today().year
        self.date = datetime.date(self.year, self.month, self.day)




import datetime

from tabulate import tabulate

def print_menu(menu, date, args):
    output_day = next((day for day in menu.days if day.id == date.weekday()), None)

    if date > menu.valid_to.date:
        # Menu is outdated
        if date.weekday() in range(0,5):
            # and it is already [monday, friday]
            print("Leider wurde für die aktuelle Woche noch keine neue Tageskarte zur Verfügung gestellt.")
            return
        if date.weekday() in range(5,7):
            # but we are still in the same week waiting for an update
            print("Leider wurde für die kommende Woche noch keine neue Tageskarte zur Verfügung gestellt.")
            return

    if date < menu.valid_from.date:
        # There is already a new menu for the upcoming week.
        # Change output day to monday
        output_day = next((day for day in menu.days if day.id == 0), None)

    if output_day is None:
        print("Heute ist nicht.")
        return

    table = []
    for meal in output_day.meals:
        row = [meal.name]
        if args.allergens:
            row.append(meal.allergens)
        if not args.no_internal:
            row.append('{:.2f}€'.format(meal.price.intern))
        if not args.no_external:
            row.append('{:.2f}€'.format(meal.price.extern))
        table.append(row)

    headers = ['Tageskarte für ' + str(date)]
    if args.allergens:
        headers.append('Allergene')
    if not args.no_internal:
        headers.append('Preis Intern')
    if not args.no_external:
        headers.append('Preis Extern')
    print(tabulate(table, headers=headers, tablefmt='orgtbl'))
    if args.allergens:
        print(menu.allergens_legend)




import os
import subprocess

def convert_menu(pdf, flattened_pdf_path, txt_path):
    with open(os.devnull, 'w') as devnull:
        subprocess.run(["gs", "-o", flattened_pdf_path, "-sDEVICE=pdfwrite", pdf], stdout=devnull, stderr=devnull)
        subprocess.run(["pdftotext", flattened_pdf_path, txt_path], stdout=devnull, stderr=devnull)
